package com.ruoyi.brewery.mapper;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysMenu;
import com.ruoyi.common.core.domain.entity.WyBreweryMenu;

/**
 * 品牌方菜单权限Mapper接口
 * 
 * @author ruoyi
 * @date 2024-12-22
 */
public interface WyBreweryMenuMapper 
{
    /**
     * 查询品牌方菜单权限
     * 
     * @param menuId 品牌方菜单权限主键
     * @return 品牌方菜单权限
     */
    public WyBreweryMenu selectWyBreweryMenuByMenuId(Long menuId);

    /**
     * 查询品牌方菜单权限列表
     * 
     * @param wyBreweryMenu 品牌方菜单权限
     * @return 品牌方菜单权限集合
     */
    public List<WyBreweryMenu> selectWyBreweryMenuList(WyBreweryMenu wyBreweryMenu);

    /**
     * 新增品牌方菜单权限
     * 
     * @param wyBreweryMenu 品牌方菜单权限
     * @return 结果
     */
    public int insertWyBreweryMenu(WyBreweryMenu wyBreweryMenu);

    /**
     * 修改品牌方菜单权限
     * 
     * @param wyBreweryMenu 品牌方菜单权限
     * @return 结果
     */
    public int updateWyBreweryMenu(WyBreweryMenu wyBreweryMenu);

    /**
     * 删除品牌方菜单权限
     * 
     * @param menuId 品牌方菜单权限主键
     * @return 结果
     */
    public int deleteWyBreweryMenuByMenuId(Long menuId);

    /**
     * 批量删除品牌方菜单权限
     * 
     * @param menuIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyBreweryMenuByMenuIds(Long[] menuIds);

    public List<WyBreweryMenu> selectMenuTreeAll();

    /**
     * 根据用户ID查询菜单
     *
     * @param userId 用户ID
     * @return 菜单列表
     */
    public List<WyBreweryMenu> selectMenuTreeByUserId(Long userId);
}
